@@ -71,6 +71,10 @@ BayonneBinder("ivrscript1")
 			(Check)&Checks::chkJoin},
 		{"recall", false, (Method)&Methods::scrRecall,
 			(Check)&Checks::chkRecall},
+		{"redial", false, (Method)&Methods::scrRedial,
+			(Check)&Checks::chkRedial},
+        {"reroute", false, (Method)&Methods::scrRedial,
+            (Check)&Checks::chkRedial},
 		{"feature", false, (Method)&Methods::scrFeature,
 			(Check)&Checks::chkFeature},
 		{"release", true, (Method)&Methods::scrRelease,
@@ -94,8 +98,12 @@ BayonneBinder("ivrscript1")
 	Bayonne::use_macros = true;
 	Bayonne::use_merge = true;
 
-	server->setValue("connect.conf", CONFIG_FILES "/connect.conf");
-	server->setValue("feature.conf", CONFIG_FILES "/feature.conf");
+	addConfig("timeslot.conf");
+	addConfig("connect.conf");
+	addConfig("feature.conf");
+	addConfig("caller.conf");
+	addConfig("dialed.conf");
+	addConfig("runlevel.conf");
 };
 
 bool Binder::select(ScriptInterp *interp)
