@@ -28,6 +28,14 @@ const char *Checks::chkJoin(Line *line, ScriptImage *img)
 	return NULL;
 }
 
+const char *Checks::chkRedial(Line *line, ScriptImage *img)
+{
+	if(line->argc > 1)
+		return "redial may have optional variable only";
+
+	return NULL;
+}
+
 const char *Checks::chkRecall(Line *line, ScriptImage *img)
 {
 	if(line->argc)
