@@ -83,6 +83,38 @@ bool Methods::scrRelease(void)
 	return true;
 }
 
+bool Methods::scrRedial(void)
+{
+	Name *scr = NULL;
+	char buf[128];
+	const char *opt = getValue(NULL);
+	const char *cid = getSymbol("session.caller");
+
+	if(!opt)
+		opt = dtmf_digits;
+
+	if(cid && !stricmp(cid, opt))
+		scr = getScript("dialed::_self_");
+
+	if(!scr)
+	{
+		snprintf(buf, sizeof(buf), "dialed::%s", opt);
+    	scr = getScript(buf);
+	}
+
+    if(scr)
+    {
+        clearStack();
+        frame[stack].script = scr;
+        frame[stack].line = frame[stack].first = scr->first;
+        frame[stack].mask = getMask();
+        return true;
+    }
+
+	error("no-route");
+	return true;
+}
+
 bool Methods::scrRecall(void)
 {
 	BayonneSession *r = getSid(var_recall);
