@@ -107,6 +107,7 @@ public:
 	const char *chkRecall(Line *line, ScriptImage *img);
 	const char *chkRing(Line *line, ScriptImage *img);
 	const char *chkFeature(Line *line, ScriptImage *img);
+	const char *chkRedial(Line *line, ScriptImage *img);
 };
 
 class Methods : public BayonneSession
@@ -126,6 +127,7 @@ public:
 	bool scrEndinput(void);
 	bool scrReconnect(void);
 	bool scrFeature(void);
+	bool scrRedial(void);
 };
 
 } // namespace
