@@ -35,6 +35,8 @@ char *Bayonne::status = NULL;
 timeout_t Bayonne::step_timer = 20;
 timeout_t Bayonne::reset_timer = 60;
 timeout_t Bayonne::exec_timer = 60000;
+unsigned Bayonne::ts_trk = 0;
+unsigned Bayonne::ts_ext = 0;
 Bayonne::RPCNode *Bayonne::RPCNode::first = NULL;
 unsigned Bayonne::RPCNode::count = 0;
 Bayonne::Traffic Bayonne::total_call_attempts;
@@ -811,6 +813,24 @@ BayonneSession *Bayonne::getSession(timeslot_t timeslot)
 	return timeslots[timeslot];
 }
 
+const char *Bayonne::getRunLevel(void)
+{
+	const char *cp = strrchr(sla, ':');
+	if(cp)
+		return ++cp;
+	else
+		return "up";
+}
+
+void Bayonne::addConfig(const char *file)
+{
+	char path[128];
+	snprintf(path, sizeof(path), "%s/%s",
+		server->getLast("config"), file);
+
+	server->setValue(file, path);
+}
+
 bool Bayonne::service(const char *id)
 {
 	bool rtn = false;
@@ -879,6 +899,7 @@ ScriptCompiler *Bayonne::reload(void)
 	compile_count = 0;
 
 	reloading.writeLock();
+	DynamicKeydata::reload();
 	img = BayonneBinder::getCompiler();
 	img->setValue("text.cr", "\r");
 	img->setValue("text.nl", "\n");
