@@ -85,6 +85,99 @@ class __EXPORT BayonneSpan;
 class __EXPORT BayonneService;
 class __EXPORT BayonneTranslator;
 class __EXPORT BayonneRPC;
+
+/**
+ * Bayonnne specific static keydata class.  This is used for configuration
+ * keys which cannot be reloaded at runtime.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short Static Keydata
+ */
+class __EXPORT StaticKeydata : public Keydata
+{
+public:
+	StaticKeydata(const char *path, Keydata::Define *defkeys = NULL, const char *homepath = NULL);
+
+	inline const char *getString(const char *id)
+		{return getLast(id);};
+
+	inline long getValue(const char *id)
+		{return getLong(id);};
+
+	inline bool getBoolean(const char *id)
+		{return getBool(id);};
+};
+
+/**
+ * Bayonne specific dynamic keydata class.  This class is used for
+ * keydata items which can be reloaded from the config file during
+ * runtime.  The normal Bayonne "reload" operatio will be used for
+ * this purpose.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short Dynamically reloadable key data class.
+ */
+class __EXPORT DynamicKeydata : public ThreadLock
+{
+private:
+	friend class __EXPORT BayonneConfig;
+	friend class __EXPORT ReconfigKeydata;
+	static DynamicKeydata *firstConfig;
+	DynamicKeydata *nextConfig;
+	const char *keypath;
+	const char *homepath;
+	Keydata *keys;
+	Keydata::Define *defkeys;
+	void loadConfig(void);
+
+protected:
+	virtual void updateConfig(Keydata *keydata);
+
+public:
+	DynamicKeydata(const char *keypath, Keydata::Define *def = NULL, const char *homepath = NULL);
+
+	const char *getString(const char *key, char *buf, size_t size);
+	long getValue(const char *key);
+	bool isKey(const char *key);
+	bool getBoolean(const char *key);
+
+	static void reload(void);
+};
+
+/**
+ * Bayonne specific reloaded keydata class.  This class is used for
+ * keydata items which can be reloaded from the config file during
+ * runtime while using keydata base for core compatibility and defaults.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short Dynamically reloadable key data class.
+ */
+class __EXPORT ReconfigKeydata : public StaticKeydata, protected DynamicKeydata
+{
+protected:
+	// use only in updateConfig method...
+	const char *updatedString(const char *id);
+	long updatedValue(const char *id);
+	timeout_t updatedSecTimer(const char *id);
+	timeout_t updatedMsecTimer(const char *id);
+	bool updatedBoolean(const char *id);
+
+	// used for special purposes for clarity, future api...
+	inline const char *getInitial(const char *id)
+		{return StaticKeydata::getString(id);};
+	inline void setInitial(const char *id, const char *val)
+		{StaticKeydata::setValue(id, val);};
+
+public:
+	ReconfigKeydata(const char *keypath, Keydata::Define *def = NULL);
+
+	const char *getString(const char *key, char *buf, size_t size);
+	timeout_t getSecTimer(const char *key);
+	timeout_t getMsecTimer(const char *key);
+	long getValue(const char *key);
+	bool isKey(const char *key);
+	bool getBoolean(const char *key);
+};
 	  
 /**
  * Generic Bayonne master class to reference various useful data types
@@ -123,6 +216,8 @@ protected:
 	static ScriptImage **localimages;
 	static char *status;
 	static ScriptCommand *server;
+	static unsigned ts_trk;
+	static unsigned ts_ext;
 	static timeslot_t ts_limit;
 	static timeslot_t ts_count;
 	static timeslot_t ts_used;
@@ -907,6 +1002,11 @@ public:
 	 */
 	static void allocateLocal(void);
 
+	/**
+	 * Add config file entry.
+	 */
+	static void addConfig(const char *cfgfile);
+
 	/**
 	 * Compute md5 hashes...
 	 *
@@ -947,6 +1047,13 @@ public:
 	 */
 	static bool service(const char *service);
 
+	/**
+	 * Get service level.
+	 *
+	 * @param return service level
+	 */
+	static const char *getRunLevel(void);
+
 	/**
 	 * Returns a session pointer for a server timeslot.  Each
 	 * server timeslot can map to a single session object.
@@ -1180,7 +1287,7 @@ public:
  * @author David Sugar <dyfet@gnutelephony.org>
  * @short Bayonne config cache for compiler.
  */
-class __EXPORT BayonneConfig : public Keydata
+class __EXPORT BayonneConfig : public DynamicKeydata
 {
 private:
 	static BayonneConfig *first;
@@ -1189,7 +1296,7 @@ private:
 	const char *id;
 
 public:
-	BayonneConfig(const char *id, Define *def, const char *path);
+	BayonneConfig(const char *id, Keydata::Define *def, const char *path);
 	BayonneConfig(const char *id, const char *path);
 	void setEnv(const char *id);
 	static BayonneConfig *get(const char *id);
@@ -1581,7 +1688,7 @@ protected:
  * @author David Sugar <dyfet@gnutelephony.org>
  * @short Bayonne driver node class.
  */
-class __EXPORT BayonneDriver : public Bayonne, public Keydata, public Mutex
+class __EXPORT BayonneDriver : public Bayonne, public ReconfigKeydata, public Mutex
 {
 protected:
 	friend class __EXPORT BayonneSession;
@@ -2240,6 +2347,8 @@ protected:
 
 	virtual void dropCall(BayonneSession *child);
 
+	virtual Name *getIncoming(BayonneSession *s);
+
 public:
 	static const char *submitRequest(const char **data);
 
