@@ -31,8 +31,8 @@ BayonneZeroconf::BayonneZeroconf(const char *t, zeroconf_family_t family)
 	zeroconf_first = this;
 }
 
-BayonneConfig::BayonneConfig(const char *tag, Define *def, const char *path) :
-Keydata(def, path)
+BayonneConfig::BayonneConfig(const char *tag, Keydata::Define *def, const char *path) :
+DynamicKeydata(path, def)
 {
 	id = tag;
 	next = first;
@@ -42,18 +42,25 @@ Keydata(def, path)
 void BayonneConfig::setEnv(const char *sym)
 {
 	char buffer[65];
-	const char *cp = getLast(sym);
+	const char *cp;
+
+	readLock();
+	cp = keys->getLast(sym);
 
 	if(!cp)
+	{
+		unlock();
 		return;
+	}
 
 	snprintf(buffer, sizeof(buffer), "%s_%s", id, sym);
 	setUpper(buffer, 0);
 	Process::setEnv(buffer, cp, true);
+	unlock();
 }
 
 BayonneConfig::BayonneConfig(const char *tag, const char *path) :
-Keydata(path)
+DynamicKeydata(path)
 {
 	id = tag;
 	next = first;
@@ -71,17 +78,19 @@ void BayonneConfig::rebuild(ScriptImage *img)
 	
 	while(cfg)
 	{
-		count = cfg->getIndex(list, 128);
+		cfg->readLock();
+		count = cfg->keys->getIndex(list, 128);
 		pos = 0;
 		while(pos < count)
 		{
 			id = list[pos++];
-			cp = cfg->getLast(id);
+			cp = cfg->keys->getLast(id);
 			if(!cp)
 				continue;
 			snprintf(buffer, sizeof(buffer), "%s.%s", cfg->id, id);
 			img->setValue(buffer, cp);
 		}
+		cfg->unlock();
 		cfg = cfg->next;
 	}
 }
