@@ -28,17 +28,13 @@ BayonneDriver *BayonneDriver::protoDriver = NULL;
 Semaphore BayonneDriver::oink(0);
 
 BayonneDriver::BayonneDriver(Keydata::Define *pairs, const char *cfg, const char *id, bool virt) :
-Keydata(pairs, cfg), Mutex()
+ReconfigKeydata(cfg, pairs), Mutex()
 {
 	name = id;
 	running = false;
 	msgport = NULL;
 	logevents = NULL;
 
-#ifdef	WIN32
-	loadFile("C:\\Program Files\\GNU Telephony\\Bayonne Config\\driver.ini", id);
-#endif
-
 	avail = 0;
 	firstIdle = lastIdle = highIdle = NULL;
 
