@@ -117,16 +117,17 @@ void BayonneSession::enterCall(void)
 
 void BayonneSession::exitCall(const char *reason)
 {
-        BayonneService *svc = BayonneService::first;
+	BayonneService *svc = BayonneService::first;
 
+	setString(var_joined, sizeof(var_joined), "none");
 	setSymbol("session.terminated", reason);
 	BayonneBinder::binder->dropCall(this);
 
-        while(svc)
-        {
-                svc->exitingCall(this);
-                svc = svc->next;
-        }
+	while(svc)
+	{
+		svc->exitingCall(this);
+		svc = svc->next;
+	}
 }
 
 void BayonneSession::incIncomingAttempts(void)
@@ -1094,29 +1095,26 @@ Script::Name *BayonneSession::attachStart(Event *event)
 		ref = true;
 	}
 
+	if(parent && event->start.scr)
+	{
+		scr = event->start.scr;
+		goto final;
+	}
+
+	cid = getSymbol("session.manager");
+	if(cid && *cid && event->start.scr)
+	{
+		scr = event->start.scr;
+		goto final;
+	}
+
+	scr = BayonneBinder::binder->getIncoming(this);
 	if(scr)
 		goto final;
 
 	if(sla[0])
 	{
 		scr = img->getScript(sla);
-		if(scr)	
-			goto final;
-	}
-
-	if(iface == IF_INET)
-		goto incoming;
-
-	did = getSymbol("session.dialed");
-	if(did)
-	{
-		snprintf(buf, sizeof(buf), "dialed::%s", did);
-		scr = img->getScript(buf);
-		if(scr)
-			goto final;
-
-		snprintf(buf, sizeof(buf), "did.%s", did);
-		scr = (Name *)img->getPointer(buf);
 		if(scr)
 			goto final;
 	}
@@ -1128,32 +1126,52 @@ Script::Name *BayonneSession::attachStart(Event *event)
 		scr = img->getScript(buf);
 		if(scr)
 			goto final;
+	}
 
-		snprintf(buf, sizeof(buf), "cid.%s", cid);
-		scr = (Name *)img->getPointer(buf);
+	did = getSymbol("session.dialed");
+	if(did && cid && !stricmp(did, cid))
+	{
+		scr = img->getScript("dialed::_self_");
 		if(scr)
 			goto final;
 	}
 
-	snprintf(buf, sizeof(buf), "timeslot::%d", timeslot);
+	if(did)
+	{
+		snprintf(buf, sizeof(buf), "dialed::%s", did);
+		scr = img->getScript(buf);
+		if(scr)
+			goto final;
+	}
+
+	scr = event->start.scr;
+	if(scr)
+		goto final;
+
+	if(iface == IF_INET)
+		goto incoming;
+
+	snprintf(buf, sizeof(buf), "timeslot::%s%d",
+		driver->getName(), timeslot - driver->getFirst());
+	scr = img->getScript(buf);
+	if(scr)
+		goto final;
+	
+	snprintf(buf, sizeof(buf), "timeslot::port%d", timeslot);
 	scr = img->getScript(buf);
 	if(scr)
 		goto final;
 
-	snprintf(buf, sizeof(buf), "ts.%d", timeslot);
-	scr = (Name *)img->getPointer(buf);
-	if(scr)
-		goto final;	
-
 	if(span)
 	{
-		snprintf(buf, sizeof(buf), "span::%d", span->id);
+		snprintf(buf, sizeof(buf), "timeslot::span%d-%d", 
+			span->id, timeslot - span->getFirst());
 		scr = img->getScript(buf);
 		if(scr)
 			goto final;
 
-		snprintf(buf, sizeof(buf), "span.%d", span->id);
-		scr = (Name *)img->getPointer(buf);
+		snprintf(buf, sizeof(buf), "timeslot::span%d", span->id);
+		scr = img->getScript(buf);
 		if(scr)
 			goto final;
 	}
@@ -1162,20 +1180,7 @@ Script::Name *BayonneSession::attachStart(Event *event)
 	if(scr)
 		goto final;
 
-	scr = (Name *)img->getPointer("ts.default");
-	if(scr)
-		goto final;
-
 incoming:
-	scr = img->getScript("dialed::default");
-	if(scr)
-		goto final;
-
-	scr = (Name *)img->getPointer("did.default");
-	if(scr)
-		goto final;
-
-
 	id = server->getLast("startup");
 	if(id)
 	{
