@@ -61,6 +61,7 @@ static Keydata::Define driver[] = {
 	{"starting", "delayed"},
 	{"threads", "5"},
 	{"realm", "Bayonne"},
+	{"hostid", "false"},
 	{"nonce", "456345766asd345"},
 #ifdef	WIN32		// use localhost default if not in conf for w32
 	{"interface", "127.0.0.1:5070"},
@@ -140,28 +141,8 @@ Assoc()
 	const char *cp, *p;
 	char buf[1024];
 
-	if(getUserdata())
-		load("~bayonne/sip");
-
 	sip_port = 5060;
 
-	cp = getLast("ack");
-	if(!cp)
-		cp = getLast("acktimer");
-
-	if(!cp)
-		cp = getLast("pickup");
-
-	if(cp)
-		pickup_timer = atol(cp);
-
-	if(pickup_timer < 10)
-		pickup_timer *= 1000;
-
-	cp = getLast("hangup");
-	if(cp)
-		hangup_timer = atol(cp);
-
 	cp = getLast("bind");
 	if(!cp)
 		cp = getLast("interface");
@@ -208,44 +189,6 @@ Assoc()
 		break;
 	}
 
-	cp = getLast("inband");
-
-	dtmf_inband = true;
-	switch(*cp)
-	{
-	case 'n':
-	case 'N':
-	case 'f':
-	case 'F':
-	case '0':
-	case 0:
-		dtmf_inband = false;
-		break;
-	}
-
-        cp = getLast("filler");
-
-        data_filler = true;
-        switch(*cp)
-        {
-        case 'n':
-        case 'N':
-        case 'f':
-        case 'F':
-        case '0':
-        case 0:
-                data_filler = false;
-                break;
-        }
-
-
-	audio_timer = atol(getLast("audio"));
-	hangup_timer -= audio_timer;
-	accept_timer = atol(getLast("accept"));
-	jitter = atoi(getLast("jitter"));
-	data_negotiate = atoi(getLast("payload"));
-	dtmf_negotiate = 0;
-
 	starting = START_DELAYED;
 
 	cp = getLast("starting");
@@ -261,14 +204,6 @@ Assoc()
 		break;
 	}
 
-	cp = getLast("dtmf");
-	if(cp)
-		dtmf_negotiate = atoi(cp);
-	if(cp && !stricmp(cp, "info"))
-		info_negotiate = true;
-	if(cp && !stricmp(cp, "sipinfo"))
-		info_negotiate = true;
-
 	memset(&info, 0, sizeof(info));
 	cp = getLast("encoding");
 	if(!stricmp(cp, "a32"))
@@ -286,15 +221,45 @@ Assoc()
 		info.rate = atol(cp);
 	info.setFraming(atol(getLast("framing")));
 	registry = false;
-	cp = server->getLast("serverconfig");
-	if(cp)
-	{
-		snprintf(buf, sizeof(buf), "%s/%s/sip.conf",
-			CONFIG_FILES, cp);
-		server->setValue("sip.conf", buf);
-	}
+	server->setValue("sip.conf", CONFIG_FILES "/sip.conf");
+	Driver::updateConfig(NULL);
+}
+
+void Driver::updateConfig(Keydata *key)
+{
+	timeout_t pickup = updatedMsecTimer("ack");
+	timeout_t hangup = updatedMsecTimer("hangup");
+	const char *dtmf = updatedString("dtmf");
+
+	audio_timer = updatedMsecTimer("audio");
+	accept_timer = updatedMsecTimer("accept");
+
+	if(!pickup)
+		pickup = updatedMsecTimer("acktimer");
+	if(!pickup)
+		pickup = updatedMsecTimer("pickup");
+
+	if(pickup < 10)
+		pickup *= 1000;
+
+	if(pickup)
+		pickup_timer = pickup;
+
+	if(hangup && audio_timer < hangup)
+		hangup_timer = hangup - audio_timer;
+
+	data_negotiate = updatedValue("payload");
+	dtmf_negotiate = updatedValue("dtmf");
+	if(dtmf && !stricmp(dtmf, "info"))
+		info_negotiate = true;
+	else if(dtmf && !stricmp(dtmf, "sipinfo"))
+		info_negotiate = true;
 	else
-		server->setValue("sip.conf", CONFIG_FILES "/sip.conf");
+		info_negotiate = false;
+
+	dtmf_inband = updatedBoolean("inband");
+	data_filler = updatedBoolean("filler");
+	jitter = updatedValue("jitter");
 }
 
 void *Driver::getMemory(size_t size)
@@ -1450,7 +1415,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	reg->transfer = ScriptChecks::findKeyword(line, "transfer");
 	reg->group = ScriptChecks::findKeyword(line, "group");
 	gateways = ScriptChecks::findKeyword(line, "gateways");
-	
+		
 	if(!reg->group)
 		reg->group = "nobody";
 
@@ -1498,6 +1463,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		reg->call_limit = atoi(cp);
 
 	cp = ScriptChecks::findKeyword(line, "framing");
+
 	if(!cp || !reg->encoding)
 		cp = "0";
 	reg->framing = atol(cp);
@@ -1965,6 +1931,7 @@ void Driver::run(void)
 	time_t now;
 	time_t last = 0;
 	bool inactive;
+	InetAddress hostid;
 
 	Bayonne::waitLoaded();
 
@@ -3014,8 +2981,6 @@ sip480:
 					from->url->username,
 					from->url->host);
 					
-			session->setConst("session.uri_remote", buf);
-
 			if(reg)
 			{
 				++reg->traffic->call_attempts.iCount;
