@@ -466,7 +466,7 @@ void Session::run(void)
 			bp = strtok_r(buffer, "\r\n", &tok);
 			if(bp)
 				Thread::sleep(1000);
-			if(bp && !strcmp(bp, Service::tcp.getLast("secret")))
+			if(bp && !strcmp(bp, Service::tcp.getString("secret")))
 				login = true;
 			else
 			{
