@@ -23,51 +23,30 @@ using namespace std;
 
 Service Service::webservice;
 bool Service::active = false;
-Keydata Service::admin("/bayonne/web/admin");
-Keydata Service::rpc("/bayonne/web/rpc");
+DynamicKeydata Service::admin("/bayonne/web/admin");
+DynamicKeydata Service::rpc("/bayonne/web/rpc");
+
+static Keydata::Define defkeys[] = {
+    {"interface", "127.0.0.1"},
+    {"port", "8055"},
+    {"backlog", "5"},
+    {"output", "2048"},
+    {"input", "1024"},
+    {"segment", "536"},
+    {"refresh", "10"},
+    {"realm", "bayonne"},
+    {"datafiles", WEBSERVER_FILES},
+    {"logfiles", LOG_FILES},
+    {"zeroconf", "yes"},
+    {NULL, NULL}};
 
 Service::Service() :
 BayonneService(0, 0), 
 BayonneZeroconf("_http._tcp"),
-Keydata("/bayonne/web/service")
+StaticKeydata("/bayonne/web/service", defkeys)
 {
-	const char *cp;
-
-	static Keydata::Define defkeys[] = {
-	{"interface", "127.0.0.1"},
-	{"port", "8055"},
-	{"backlog", "5"},
-	{"output", "2048"},
-	{"input", "1024"},
-	{"segment", "536"},
-	{"refresh", "10"},
-	{"realm", "bayonne"},
-	{"datafiles", WEBSERVER_FILES}, 
-	{"logfiles", LOG_FILES},
-	{"zeroconf", "yes"},
-	{NULL, NULL}};
-
-	if(Bayonne::getUserdata())
-	{
-	        load("~bayonne/webservice");
-		admin.load("~bayonne/webadmin");
-		rpc.load("~bayonne/webrpc");
-	}
-
-	load(defkeys);
-#ifdef	WIN32
-	loadFile("C:\\Program Files\\GNU Telephony\\Bayonne Config\\web.ini", "service");
-#endif
-	cp = getLast("zeroconf");
-	switch(*cp)
-	{
-	case 'y':
-	case 'Y':
-	case 't':
-	case 'T':
-	case '1':
-		zeroconf_port = atoi(getLast("port"));
-	}
+	if(getBoolean("zeroconf"))
+		zeroconf_port = getValue("port");
 }
 
 void Service::stopService(void)
@@ -83,7 +62,7 @@ void Service::run(void)
 	TCP *tcp;
 	const char *cp;
 	char *tok;
-	char *p = (char *)getLast("interface");
+	char *p = (char *)getString("interface");
 	unsigned count = 0, ipv6_count = 0;
 
 	slog.info("webservice started");
