@@ -176,28 +176,26 @@ void Session::sendError(const char *text, const char *cttype, size_t size)
 void Session::sendAuth(const char *text, const char *cttype, size_t size)
 {
 	char buffer[256];
-	const char *realm = Service::webservice.getLast("realm");
-        sendText(text);
-        sendText("Server: Bayonne/" VERSION "\r\n");
+	const char *realm = Service::webservice.getString("realm");
+	sendText(text);
+	sendText("Server: Bayonne/" VERSION "\r\n");
 	sendText("Pragma: no-cache\r\n");
 	sendText("Cache-Control: no-cache\r\n");
-        sendText("Connection: close\r\n");
+	sendText("Connection: close\r\n");
 	snprintf(buffer, sizeof(buffer),
 		"WWW-Authenticate: Basic realm=\"%s\"\r\n", realm);
 	sendText(buffer);
-        if(cttype)
-        {
-                snprintf(buffer, sizeof(buffer),
-                        "Content-Type: %s\r\n", cttype);
-                sendText(buffer);
-        }
-	if(size)
+	if(cttype)
 	{
-		snprintf(buffer, sizeof(buffer),
-			"Content-Length: %ld\r\n", (long)size);
+		snprintf(buffer, sizeof(buffer), "Content-Type: %s\r\n", cttype);
 		sendText(buffer);
 	}
-        sendText("\r\n");
+	if(size)
+	{
+		snprintf(buffer, sizeof(buffer), "Content-Length: %ld\r\n", (long)size);
+		sendText(buffer);
+	}
+	sendText("\r\n");
 }
 
 #ifndef	ECONNRESET
@@ -256,6 +254,7 @@ void Session::run(void)
 	char *tok;
 	const char *ext;
 	char agent[65];
+	char secret_buf[65];
 	unsigned xmlsize = 0;
 	bool xmltext = false;
 
@@ -367,7 +366,7 @@ timeout:
 	{
 		if(!req_auth || !userid || !passwd)
 			xmlFault(401, "Authorization Required");
-		secret = Service::webservice.rpc.getLast(userid);
+		secret = Service::webservice.rpc.getString(userid, secret_buf, sizeof(secret_buf));
 		if(!secret || strcmp(secret, passwd))
 			xmlFault(401, "Authorization Invalid");
 	}
@@ -375,7 +374,7 @@ timeout:
 	{
 		if(!req_auth || !userid || !passwd)
 			xmlFault(401, "Authorization Required");
-		secret = Service::webservice.admin.getLast(userid);
+		secret = Service::webservice.admin.getString(userid, secret_buf, sizeof(secret_buf));
 		if(!secret || strcmp(secret, passwd))
 			xmlFault(401, "Authorization Invalid");
 	}
@@ -390,7 +389,7 @@ timeout:
 
 		if(userid)
 		{
-			secret = Service::webservice.rpc.getLast(userid);
+			secret = Service::webservice.rpc.getString(userid, secret_buf, sizeof(secret_buf));
 			if(secret && passwd)
 				if(!strcmp(secret, passwd))
 					transport.authorized = true;
